@@ -175,6 +175,18 @@ public interface MailContentType extends ContentType {
      */
     ResourceInputStream getMailAttachmentAsStream(Session session, String folderId, String mailId, String attachmentId) throws USMException;
 
+    /**
+     * Retrieves the specified mail attachment for a mail as binary data that can be read from the provided InputStream. The attachment is provided as the ID that was previously returned by an OX getStructuredMail-call
+     * 
+     * @param session
+     * @param folderId
+     * @param mailId
+     * @param structureId
+     * @return the resource object
+     * @throws USMException
+     */
+    ResourceInputStream getMailAttachmentStreamFromStructureId(Session session, String folderId, String mailId, String structureId) throws USMException;
+
     /**
      * Retrieves a mail from the server as structured mail object. The result is returned as JSONObject as it can not be stored in the
      * DataObject itself.
