@@ -60,17 +60,18 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class DateDataType extends AbstractDataType<Long> {
-	public static final String NAME = "Date";
-
-	public String getName() {
-		return NAME;
+	
+    public DateDataType() {
+	    super("Date");
 	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) {
 		parent.put(value);
 	}
 
-	public Long checkValue(Object o) {
+	@Override
+    public Long checkValue(Object o) {
 		if (o == null)
 			return null;
 		if (o instanceof Long)
@@ -80,15 +81,18 @@ public class DateDataType extends AbstractDataType<Long> {
 		return ((Number) o).longValue();
 	}
 
-	public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Long extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? null : array.getLong(index);
 	}
 
-	public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Long extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		return jsonObject.isNull(field) ? null : jsonObject.getLong(field);
 	}
 
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, (value == null) ? JSONObject.NULL : value);
 	}
 
