@@ -60,35 +60,39 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class NumberDataType extends AbstractDataType<Number> {
-	public static final String NAME = "Number";
-
-	public void addToJSONArray(Session session, JSONArray parent, Object object) throws JSONException {
-		parent.put((Number) object);
+	
+	public NumberDataType() {
+	    super("Number");
 	}
 
-	public Number checkValue(Object o) {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object object) {
+		parent.put(object);
+	}
+
+	@Override
+    public Number checkValue(Object o) {
 		if (o != null && !(o instanceof Number))
 			generateTypeError(o);
 		return (Number) o;
 	}
 
-	public Number extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Number extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		if (array.isNull(index))
 			return null;
 		return convertToNumber(array.get(index));
 	}
 
-	public Number extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Number extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		if (jsonObject.isNull(field))
 			return null;
 		return convertToNumber(jsonObject.get(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
 		parent.put(field, (object == null) ? JSONObject.NULL : (Number) object);
 	}
 }
