@@ -60,36 +60,40 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class StringDataType extends AbstractDataType<String> {
-	public static final String NAME = "String";
+	
+    public StringDataType() {
+        super("String");
+    }
 
-	public String checkValue(Object o) {
+	@Override
+    public String checkValue(Object o) {
 		if (o == null)
 			return null;
 		String s = o.toString();
 		return (s.length() == 0) ? null : s;
 	}
 
-	public String extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public String extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		return jsonObject.isNull(field) ? null : jsonObject.getString(field);
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
 	public Object checkValueForWrite(Object o) {
 		return (o == null) ? JSONObject.NULL : String.valueOf(o);
 	}
 
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
 		parent.put(field, checkValueForWrite(object));
 	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object object) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object object) {
 		parent.put(checkValueForWrite(object));
 	}
 
-	public String extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public String extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? null : array.getString(index);
 	}
 }
