@@ -233,6 +233,7 @@ public interface Session extends Serializable {
      * @param date
      */
     void setStartDate(long date);
+    
 
     /**
      * Used for requests which need date range as parameter, some ContentTypes require a date range to be specified for their requests to
@@ -242,6 +243,46 @@ public interface Session extends Serializable {
      * @param date
      */
     void setEndDate(long date);
+    
+    /**
+     * Used for calendar specific requests which need date range as parameter.
+     * This value overwrites the global value getStartDate().  
+     * Default value is 0l.  <br>
+     * This field is not persistent, it must be reinitialized by the SessionInitializer.
+     * 
+     * @return start of the date range for calendar associated with Session.
+     */
+    long getCalendarStartDate();
+    
+    /**
+     * Used for calendar specific requests which need date range as parameter.
+     * This value overwrites the global value getEndDate().  
+     * Default value is Long.MAX_VALUE.  <br>
+     * This field is not persistent, it must be reinitialized by the SessionInitializer.
+     * 
+     * @return start of the date range for calendar associated with Session.
+     */
+    long getCalendarEndDate();
+    
+    /**
+     * Used for calendar specific requests which need date range as parameter.
+     * This value overwrites the global value which can be set via setStartDate().  
+     * Default value is 0l.  <br>
+     * This field is not persistent, it must be reinitialized by the SessionInitializer.
+     * 
+     * @return start of the date range for calendar associated with Session.
+     */
+    void setCalendarStartDate(long date);
+    
+    /**
+     * Used for calendar specific requests which need date range as parameter.
+     * This value overwrites the global value which can be set via setEndDate().  
+     * Default value is Long.MAX_VALUE.  <br>
+     * This field is not persistent, it must be reinitialized by the SessionInitializer.
+     * 
+     * @return start of the date range for calendar associated with Session.
+     */
+    void setCalendarEndDate(long date);
 
     /**
      * Sets a limit for the number of mails that will be reported when syncing a folder. If on the server more mails than the specified
