@@ -56,20 +56,21 @@ import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
 import java.util.List;
 import java.util.Map;
-import com.openexchange.usm.api.contenttypes.ContactContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.PictureConversionException;
-import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.contact.ContactConstants;
+import com.openexchange.usm.api.contenttypes.contact.ContactContentType;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.datatypes.PIMAttachmentsDataType;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
+import com.openexchange.usm.api.exceptions.PictureConversionException;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractContentType;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.contacts.ContactDistributionMemberDataType;
 import com.openexchange.usm.datatypes.contacts.ImageDataType;
 
@@ -85,13 +86,13 @@ public class ContactContentTypeImpl extends AbstractContentType implements Conta
 
 	private static final ContentTypeField[] FIELDS = {
 	//Common object data
-			new ContentTypeField(1, UtilConstants.FIELD_ID, STRING, false, true, false, false),// Object ID
-			new ContentTypeField(20, UtilConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder. 
-			new ContentTypeField(2, UtilConstants.CREATED_BY, STRING), //User ID of the user who created this object. 
-			new ContentTypeField(3, UtilConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object. 
-			new ContentTypeField(4, UtilConstants.CREATION_DATE, TIME), //Date and time of creation.
-			new ContentTypeField(5, UtilConstants.LAST_MODIFIED, TIME), //Date and time of the last modification. 
-			new ContentTypeField(100, UtilConstants.CATEGORIES, STRING), //Array - Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object. 
+			new ContentTypeField(1, CommonConstants.FIELD_ID, STRING, false, true, false, false),// Object ID
+			new ContentTypeField(20, CommonConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder. 
+			new ContentTypeField(2, CommonConstants.CREATED_BY, STRING), //User ID of the user who created this object. 
+			new ContentTypeField(3, CommonConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object. 
+			new ContentTypeField(4, CommonConstants.CREATION_DATE, TIME), //Date and time of creation.
+			new ContentTypeField(5, CommonConstants.LAST_MODIFIED, TIME), //Date and time of the last modification. 
+			new ContentTypeField(100, CommonConstants.CATEGORIES, STRING), //Array - Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object. 
 			//Not present in folder objects. 
 			new ContentTypeField(101, ContactConstants.PRIVATE_FLAG, BOOLEAN), //Overrides folder permissions in shared private folders: When true, this object is not visible to anyone except the owner. Not present in folder objects. 
 			new ContentTypeField(104, ContactConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments 
@@ -205,7 +206,7 @@ public class ContactContentTypeImpl extends AbstractContentType implements Conta
 			//			new ContentTypeField(606, "image1_url", STRING)
 			//			new ContentTypeField(570, "image1", STRING),
 			//			new ContentTypeField(601, "image1_content_type", STRING),
-			new ContentTypeField(105, UtilConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
+			new ContentTypeField(105, CommonConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
 			new ContentTypeField(610, ContactConstants.YOMI_FIRST_NAME, 1, STRING),
 			new ContentTypeField(611, ContactConstants.YOMI_LAST_NAME, 1, STRING),
 			new ContentTypeField(612, ContactConstants.YOMI_COMPANY, 1, STRING),
@@ -215,17 +216,13 @@ public class ContactContentTypeImpl extends AbstractContentType implements Conta
 
 	private ContactContentTypeTransferHandler _transferHandler;
 
-	/**
-	 * Constructor is package private to discourage access from outside the bundle (but to allow usage in test cases)
-	 */
-	ContactContentTypeImpl() {
-	}
-
-	public ContentTypeField[] getFields() {
+	@Override
+    public ContentTypeField[] getFields() {
 		return FIELDS;
 	}
 
-	public String getID() {
+	@Override
+    public String getID() {
 		return DefaultContentTypes.CONTACTS_ID;
 	}
 
@@ -234,7 +231,8 @@ public class ContactContentTypeImpl extends AbstractContentType implements Conta
 		return getID();
 	}
 
-	public ContentTypeTransferHandler getTransferHandler() {
+	@Override
+    public ContentTypeTransferHandler getTransferHandler() {
 		return _transferHandler;
 	}
 
@@ -258,35 +256,42 @@ public class ContactContentTypeImpl extends AbstractContentType implements Conta
 		return true;
 	}
 
-	public byte[] getPictureData(DataObject dataObject, String pictureFormat, int maxSize)
+	@Override
+    public byte[] getPictureData(DataObject dataObject, String pictureFormat, int maxSize)
 			throws AuthenticationFailedException, OXCommunicationException, PictureConversionException {
 		return _transferHandler.getPictureData(dataObject, pictureFormat, maxSize);
 	}
 
-	public Map<String, DataObject[]> resolveRecipients(List<String> toList, Session session, BitSet requestedFields)
+	@Override
+    public Map<String, DataObject[]> resolveRecipients(List<String> toList, Session session, BitSet requestedFields)
 			throws AuthenticationFailedException, OXCommunicationException, UnsupportedContentOperationException, InternalUSMException {
 		return _transferHandler.resolveRecipients(toList, session, requestedFields);
 	}
 
-	public int getCode() {
+	@Override
+    public int getCode() {
 		return DefaultContentTypes.CONTACTS_CODE;
 	}
 
-	public boolean supportsPIMAttachments() {
+	@Override
+    public boolean supportsPIMAttachments() {
 		return true;
 	}
 
-	public Object getObjectGroupOwner(DataObject object) {
+	@Override
+    public Object getObjectGroupOwner(DataObject object) {
 		return object.getID();
 	}
 
-	public DataObject[] getAllUsers(Session session, BitSet requestedFields) throws AuthenticationFailedException,
+	@Override
+    public DataObject[] getAllUsers(Session session, BitSet requestedFields) throws AuthenticationFailedException,
 			OXCommunicationException, UnsupportedContentOperationException, InternalUSMException {
 		return _transferHandler.getAllUsers(session, requestedFields);
 	}
 
-	public void getUser(DataObject object, BitSet requestedFields) throws AuthenticationFailedException,
-			OXCommunicationException, UnsupportedContentOperationException, InternalUSMException {
+	@Override
+    public void getUser(DataObject object, BitSet requestedFields) throws AuthenticationFailedException,
+			OXCommunicationException, InternalUSMException, UnsupportedContentOperationException {
 		_transferHandler.getUser(object, requestedFields);
 	}
 
