@@ -431,6 +431,14 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
                 e);
         } finally {
             Toolkit.close(tempFile);
+            if (tempFile != null) {
+                try {
+                    TempFileStorage.deleteTempFile(object.getSession(), i.getTempId());
+                } catch (IOException e) {
+                    if (LOG.isDebugEnabled())
+                        LOG.debug("Can't delete temp file of contact image " + e);
+                }
+            }
         }
     }
 
