@@ -78,12 +78,15 @@ public class Image implements Serializable {
     private final transient String _contentType;
 
     private final transient byte[] _data;
+    
+    private final transient String _tempid;
 
     public Image() {
         _lastModified = 0L;
         _url = null;
         _contentType = null;
         _data = null;
+        _tempid = null;
     }
 
     Image(long lastModified, String url, String contentType) {
@@ -91,6 +94,7 @@ public class Image implements Serializable {
         _url = url;
         _contentType = contentType;
         _data = null;
+        _tempid = null;
     }
 
     public Image(long lastModified, String contentType, byte[] data) {
@@ -98,6 +102,15 @@ public class Image implements Serializable {
         _url = null;
         _contentType = contentType;
         _data = data;
+        _tempid = null;
+    }
+
+    public Image(String tempid, String contentType) {
+        _lastModified = System.currentTimeMillis();
+        _url = null;
+        _contentType = contentType;
+        _data = null;
+        _tempid = tempid;
     }
 
     /**
@@ -154,4 +167,8 @@ public class Image implements Serializable {
             return false;
         return true;
     }
+
+    public String getTempId() {
+        return _tempid;
+    }
 }
