@@ -46,20 +46,20 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.contenttypes.folder.impl;
 
-import org.apache.commons.logging.Log;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
-import com.openexchange.usm.ox_json.OXJSONAccess;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
 
-public class Folder2ContentTypeTransferHandlerImpl extends FolderContentTypeTransferHandlerImpl{
+public class Folder2ContentTypeTransferHandlerImpl extends FolderContentTypeTransferHandlerImpl {
 
-	public Folder2ContentTypeTransferHandlerImpl(FolderContentTypeImpl contentType, Log log, OXJSONAccess ajaxAccess) {
-		super(contentType, log, ajaxAccess);
-	}
+    public Folder2ContentTypeTransferHandlerImpl(FolderContentTypeImpl contentType, OXJSONAccess ajaxAccess) {
+        super(contentType, ajaxAccess);
+    }
 
-	@Override
-	protected String getOXAjaxAccessPath() {
-		return UtilConstants.VIRTUAL_FOLDER_PATH;
-	}
+    @Override
+    protected String getOXAjaxAccessPath() {
+        return CommonConstants.VIRTUAL_FOLDER_PATH;
+    }
 }
