@@ -46,6 +46,7 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.datatypes.folder;
 
 import org.json.JSONArray;
@@ -55,32 +56,35 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class FolderPermissionDataType extends AbstractDataType<FolderPermission> {
-	public static final String NAME = "FolderPermission";
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
-		parent.put(((FolderPermission) value).toJSONObject());
-	}
+    public FolderPermissionDataType() {
+        super("FolderPermission");
+    }
 
-	public FolderPermission checkValue(Object o) {
-		if (o != null && !(o instanceof FolderPermission))
-			generateTypeError(o);
-		return (FolderPermission) o;
-	}
+    @Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+        parent.put(((FolderPermission) value).toJSONObject());
+    }
 
-	public FolderPermission extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
-		return array.isNull(index) ? new FolderPermission() : new FolderPermission(array.getJSONObject(index));
-	}
+    @Override
+    public FolderPermission checkValue(Object o) {
+        if (o != null && !(o instanceof FolderPermission))
+            generateTypeError(o);
+        return (FolderPermission) o;
+    }
 
-	public FolderPermission extractFromJSONObject(Session session, JSONObject jsonObject, String field)
-			throws JSONException {
-		return jsonObject.isNull(field) ? new FolderPermission() : new FolderPermission(jsonObject.getJSONObject(field));
-	}
+    @Override
+    public FolderPermission extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+        return array.isNull(index) ? new FolderPermission() : new FolderPermission(array.getJSONObject(index));
+    }
 
-	public String getName() {
-		return NAME;
-	}
+    @Override
+    public FolderPermission extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+        return jsonObject.isNull(field) ? new FolderPermission() : new FolderPermission(jsonObject.getJSONObject(field));
+    }
 
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
-		parent.put(field, ((FolderPermission) value).toJSONObject());
-	}
+    @Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+        parent.put(field, ((FolderPermission) value).toJSONObject());
+    }
 }
