@@ -46,75 +46,84 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.contenttypes.groups.impl;
 
 import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.GroupsContentType;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.groups.GroupsConstants;
+import com.openexchange.usm.api.contenttypes.groups.GroupsContentType;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.contenttypes.util.AbstractContentType;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 
 public class GroupsContentTypeImpl extends AbstractContentType implements GroupsContentType {
 
-	private static final ContentTypeField[] FIELDS = {
-			new ContentTypeField(-1800, UtilConstants.FIELD_ID, STRING, false, true, false, false), //ID 
-			new ContentTypeField(-1801, UtilConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder. Dummy field. Always empty
-			new ContentTypeField(-1802, GroupsConstants.DISPLAY_NAME, STRING), //Display Name 
-			new ContentTypeField(-1803, GroupsConstants.NAME, STRING), //Name with character restrictions 
-			new ContentTypeField(-1804, GroupsConstants.MEMBERS, STRING, true), //Array of group member id's  
-	};
+    private static final ContentTypeField[] FIELDS = {
+        new ContentTypeField(-1800, CommonConstants.FIELD_ID, STRING, false, true, false, false), // ID
+        new ContentTypeField(-1801, CommonConstants.FOLDER_ID, STRING, false, false, true, false), // Object ID of the parent folder. Dummy
+                                                                                                   // field. Always empty
+        new ContentTypeField(-1802, GroupsConstants.DISPLAY_NAME, STRING), // Display Name
+        new ContentTypeField(-1803, GroupsConstants.NAME, STRING), // Name with character restrictions
+        new ContentTypeField(-1804, GroupsConstants.MEMBERS, STRING, true), // Array of group member id's
+    };
 
-	private GroupsContentTypeTransferHandler _transferHandler;
+    private GroupsContentTypeTransferHandler _transferHandler;
 
-	public int getCode() {
-		return DefaultContentTypes.GROUPS_CODE;
-	}
+    @Override
+    public int getCode() {
+        return DefaultContentTypes.GROUPS_CODE;
+    }
 
-	public ContentTypeField[] getFields() {
-		return FIELDS;
-	}
+    @Override
+    public ContentTypeField[] getFields() {
+        return FIELDS;
+    }
 
-	public String getID() {
-		return DefaultContentTypes.GROUPS_ID;
-	}
+    @Override
+    public String getID() {
+        return DefaultContentTypes.GROUPS_ID;
+    }
 
-	public Object getObjectGroupOwner(DataObject object) {
-		return object.getID();
-	}
+    @Override
+    public Object getObjectGroupOwner(DataObject object) {
+        return object.getID();
+    }
 
-	public ContentTypeTransferHandler getTransferHandler() {
-		return _transferHandler;
-	}
+    @Override
+    public ContentTypeTransferHandler getTransferHandler() {
+        return _transferHandler;
+    }
 
-	public void setTransferHandler(GroupsContentTypeTransferHandler transferHandler) {
-		_transferHandler = transferHandler;
-	}
+    public void setTransferHandler(GroupsContentTypeTransferHandler transferHandler) {
+        _transferHandler = transferHandler;
+    }
 
-	public boolean supportsPIMAttachments() {
-		return false;
-	}
+    @Override
+    public boolean supportsPIMAttachments() {
+        return false;
+    }
 
-	@Override
-	public int hashCode() {
-		return 191731;
-	}
+    @Override
+    public int hashCode() {
+        return 191731;
+    }
 
-	@Override
-	public boolean equals(Object obj) {
-		if (this == obj)
-			return true;
-		if (obj == null)
-			return false;
-		if (!(obj instanceof GroupsContentType))
-			return false;
-		return true;
-	}
+    @Override
+    public boolean equals(Object obj) {
+        if (this == obj)
+            return true;
+        if (obj == null)
+            return false;
+        if (!(obj instanceof GroupsContentType))
+            return false;
+        return true;
+    }
 
-	@Override
-	public boolean canBeFolderElementsContentType() {
-		return false;
-	}
+    @Override
+    public boolean canBeFolderElementsContentType() {
+        return false;
+    }
 }
