@@ -158,6 +158,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     public void sendMail(String mail, Session session) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(SRC, ONE);
+        // backend shall overwrite existing message-id headers (bug 38207)
+        parameters.put("new", "true");
         JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, mail);
         checkResult(result, JSONResultType.JSONObject);
     }
@@ -165,6 +167,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     public void sendMail(InputStreamProvider streamProvider, Session session) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(SRC, ONE);
+        // backend shall overwrite existing message-id headers (bug 38207)
+        parameters.put("new", "true");
         JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, streamProvider);
         checkResult(result, JSONResultType.JSONObject);
     }
@@ -198,6 +202,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         parameters.put(CommonConstants.ID, mailId);
         parameters.put(MailConstants.ATTACHMENT, attachmentId);
         parameters.put(SAVE, ONE);
+        parameters.put(UNSEEN, ONE);
         parameters.put(CommonConstants.ACTION, MailConstants.ATTACHMENT);
         return parameters;
     }
