@@ -77,6 +77,7 @@ public class MailAttachment implements Serializable {
 	public static final String FILENAME = "filename";
 	public static final String SIZE = "size";
 	public static final String DISP = "disp";
+    public static final String CID = "cid";
 
 	//Object ID (unique only inside the same message) 
 	private final String _id;
@@ -90,6 +91,8 @@ public class MailAttachment implements Serializable {
 	private final int _size;
 	//Attachment's disposition: null, inline, attachment or alternative. 
 	private final String _disp;
+    //Attachment's content-ID. 
+    private final String _cid;
 
 	public MailAttachment(String id, String contentType, String content, String filename, int size, String disp) {
 		_id = id;
@@ -98,6 +101,7 @@ public class MailAttachment implements Serializable {
 		_filename = filename;
 		_size = size;
 		_disp = disp;
+		_cid = "";
 	}
 
 	public MailAttachment() {
@@ -107,7 +111,8 @@ public class MailAttachment implements Serializable {
 		_filename = "";
 		_size = 0;
 		_disp = "";
-	}
+        _cid = "";
+   }
 
 	public MailAttachment(JSONObject jSONObject) throws JSONException {
 		_id = jSONObject.has(OBJECTID) ? jSONObject.getString(OBJECTID) : null;
@@ -116,6 +121,7 @@ public class MailAttachment implements Serializable {
 		_filename = jSONObject.has(FILENAME) ? jSONObject.getString(FILENAME) : "";
 		_size = jSONObject.has(SIZE) ? jSONObject.getInt(SIZE) : -1;
 		_disp = jSONObject.has(DISP) ? jSONObject.getString(DISP) : "";
+        _cid = jSONObject.has(CID) ? jSONObject.getString(CID) : "";
 	}
 
 	public String getId() {
@@ -142,6 +148,10 @@ public class MailAttachment implements Serializable {
 		return _disp;
 	}
 
+    public String getCid() {
+        return _cid;
+    }
+	
 	@Override
 	public int hashCode() {
 		final int prime = 37;
@@ -152,6 +162,7 @@ public class MailAttachment implements Serializable {
 		result = prime * result + _filename.hashCode();
 		result = prime * result + _size;
 		result = prime * result + _disp.hashCode();
+        result = prime * result + _cid.hashCode();
 		return result;
 	}
 
@@ -188,13 +199,15 @@ public class MailAttachment implements Serializable {
 			return false;
 		if (_disp != null && !_disp.equals(other._disp))
 			return false;
+        if (_cid != null && !_cid.equals(other._cid))
+            return false;
 		return true;
 	}
 
 	@Override
 	public String toString() {
 		return '{' + OBJECTID + ':' + _id + ';' + CONTENTTYPE + ':' + _contentType + ';' + CONTENT + ':' + _content
-				+ ';' + FILENAME + ':' + _filename + ';' + SIZE + ':' + _size + ';' + DISP + ':' + _disp + '}';
+				+ ';' + FILENAME + ':' + _filename + ';' + SIZE + ':' + _size + ';' + DISP + ':' + _disp + ';' + CID + ':' + _cid + '}';
 	}
 
 	public JSONObject toJSONObject() throws JSONException {
@@ -205,6 +218,7 @@ public class MailAttachment implements Serializable {
 		js.put(FILENAME, _filename);
 		js.put(SIZE, _size);
 		js.put(DISP, _disp);
+        js.put(CID, _cid);
 		return js;
 	}
 }
