@@ -55,17 +55,18 @@ import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER_NOT_NULL;
 import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
 import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.io.Serializable;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.TaskContentType;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.task.TaskConstants;
+import com.openexchange.usm.api.contenttypes.task.TaskContentType;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.datatypes.PIMAttachmentsDataType;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.DeserializationFailedException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.contenttypes.util.AbstractContentType;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.tasks.calendar.CommonCalendarTasksFieldNames;
 import com.openexchange.usm.datatypes.tasks.calendar.ParticipantIdentifierDataType;
 import com.openexchange.usm.datatypes.tasks.calendar.UserParticipantObjectDataType;
@@ -79,15 +80,15 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 
 	private static final ContentTypeField[] FIELDS = {
 	//Common object data
-			new ContentTypeField(1, UtilConstants.FIELD_ID, STRING, false, true, false, false), //Object ID
-			new ContentTypeField(20, UtilConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder.
-			new ContentTypeField(2, UtilConstants.CREATED_BY, STRING), //User ID of the user who created this object.
-			new ContentTypeField(3, UtilConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object.
-			new ContentTypeField(4, UtilConstants.CREATION_DATE, TIME), //Date and time of creation.
-			new ContentTypeField(5, UtilConstants.LAST_MODIFIED, TIME), //Date and time of the last modification.
-			new ContentTypeField(100, UtilConstants.CATEGORIES, STRING), // Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object.
-			new ContentTypeField(101, UtilConstants.PRIVATE_FLAG, BOOLEAN), //Overrides folder permissions in shared private folders: When true, this object is not visible to anyone except the owner.
-			new ContentTypeField(104, UtilConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments
+			new ContentTypeField(1, CommonConstants.FIELD_ID, STRING, false, true, false, false), //Object ID
+			new ContentTypeField(20, CommonConstants.FOLDER_ID, STRING, false, false, true, false), //Object ID of the parent folder.
+			new ContentTypeField(2, CommonConstants.CREATED_BY, STRING), //User ID of the user who created this object.
+			new ContentTypeField(3, CommonConstants.MODIFIED_BY, STRING), //User ID of the user who last modified this object.
+			new ContentTypeField(4, CommonConstants.CREATION_DATE, TIME), //Date and time of creation.
+			new ContentTypeField(5, CommonConstants.LAST_MODIFIED, TIME), //Date and time of the last modification.
+			new ContentTypeField(100, CommonConstants.CATEGORIES, STRING), // Each element is a string, naming a category. Order is preserved. Changing the order counts as modification of the object.
+			new ContentTypeField(101, CommonConstants.PRIVATE_FLAG, BOOLEAN), //Overrides folder permissions in shared private folders: When true, this object is not visible to anyone except the owner.
+			new ContentTypeField(104, CommonConstants.NUMBER_OF_ATTACHMENTS, NUMBER), //Number of attachments
 			//Detailed task and appointment data
 			new ContentTypeField(200, CommonCalendarTasksFieldNames.TITLE, STRING), //Short description.
 			new ContentTypeField(201, CommonCalendarTasksFieldNames.START_DATE, TIME), //Inclusive start of the event as Date for tasks and whole day appointments and Time for normal appointments
@@ -121,23 +122,19 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 			new ContentTypeField(314, TaskConstants.COMPANIES, STRING), //XXX: Type is missing in the HTTP_API docs
 			new ContentTypeField(315, TaskConstants.DATE_COMPLETED, DATE), //XXX: Type is missing in the HTTP_API docs
 			new ContentTypeField(102, TaskConstants.COLOR_LABEL, NUMBER), // Number from 1-10
-			new ContentTypeField(105, UtilConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
+			new ContentTypeField(105, CommonConstants.ATTACHMENTS_LAST_MODIFIED, new PIMAttachmentsDataType()), // New complex field that contains attachments_last_modified for updates and additionally an array PIMAttachment for persistent storing in the SyncState
 			new ContentTypeField(223, CommonCalendarTasksFieldNames.UID, STRING), //the UID of the task
 	};
 
 	private TaskContentTypeTransferHandlerImpl _transferHandler;
 
-	/**
-	 * Constructor is package private to discourage access from outside the bundle (but to allow usage in test cases)
-	 */
-	TaskContentTypeImpl() {
-	}
-
-	public ContentTypeField[] getFields() {
+	@Override
+    public ContentTypeField[] getFields() {
 		return FIELDS;
 	}
 
-	public String getID() {
+	@Override
+    public String getID() {
 		return DefaultContentTypes.TASK_ID;
 	}
 
@@ -146,7 +143,8 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 		return getID();
 	}
 
-	public ContentTypeTransferHandler getTransferHandler() {
+	@Override
+    public ContentTypeTransferHandler getTransferHandler() {
 		return _transferHandler;
 	}
 
@@ -170,20 +168,24 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 		return true;
 	}
 
-	public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
+	@Override
+    public void confirm(DataObject object, int response) throws AuthenticationFailedException, OXCommunicationException {
 		_transferHandler.confirm(object, response);
 	}
 
-	public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
+	@Override
+    public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
 			OXCommunicationException {
 		_transferHandler.confirm(object, response, confirmMessage);
 	}
 
-	public int getCode() {
+	@Override
+    public int getCode() {
 		return DefaultContentTypes.TASK_CODE;
 	}
 
-	public boolean supportsPIMAttachments() {
+	@Override
+    public boolean supportsPIMAttachments() {
 		return true;
 	}
 
@@ -202,7 +204,8 @@ public class TaskContentTypeImpl extends AbstractContentType implements TaskCont
 		super.deserializeData(data, offset, fieldContent);
 	}
 
-	public Object getObjectGroupOwner(DataObject object) {
+	@Override
+    public Object getObjectGroupOwner(DataObject object) {
 		return object.getID();
 	}
 }
