@@ -1035,8 +1035,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         parameters.put(CommonConstants.COLUMNS, _COLUMNS_ID_AND_LAST_MODIFIED);
         addExtraTimestampListParameters(parameters, folder.getSession());
         Session session = folder.getSession();
-        parameters.put(CommonConstants.START, String.valueOf(session.getStartDate()));
-        parameters.put(CommonConstants.END, String.valueOf(session.getEndDate()));
+        addTimeLimitParameters(parameters, session);
         addObjectsLimitParameters(folder.getSession(), parameters);
         long defaultTimestamp = System.currentTimeMillis();
         JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_ALL, folder.getSession(), parameters);
@@ -1053,6 +1052,11 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         }
     }
 
+    protected void addTimeLimitParameters(Map<String, String> parameters, Session session) {
+        parameters.put(CommonConstants.START, String.valueOf(session.getStartDate()));
+        parameters.put(CommonConstants.END, String.valueOf(session.getEndDate()));
+    }
+
     protected void addExtraTimestampListParameters(Map<String, String> parameters, Session session) {
     }
     
