@@ -53,6 +53,8 @@ import java.sql.Connection;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.Set;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.tools.update.Tools;
@@ -68,6 +70,8 @@ import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
  */
 public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
 
+    private static final Log LOG = LogFactory.getLog(USMCreatePrimaryKeyUpdateTask.class);
+
     private static class PrimaryKeyMappingInfo {
 
         public final String _tableName;
@@ -93,6 +97,7 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
         super(provider);
     }
 
+    @Override
     public String[] getDependencies() {
         return new String[] { USMTablesUpdateTaskV2.class.getName(), USMUUIDTablesUpdateTaskV2.class.getName() };
     }
@@ -119,14 +124,14 @@ public class USMCreatePrimaryKeyUpdateTask extends USMBaseUpdateTaskV2 {
         }
     }
 
-    private Statement dropIndexAndAddPrimaryKey(Connection con, Statement stmt, PrimaryKeyMappingInfo info) throws SQLException {
+    private static Statement dropIndexAndAddPrimaryKey(Connection con, Statement stmt, PrimaryKeyMappingInfo info) throws SQLException {
         Set<String> indexes = USMBaseUpdateTask.getTableIndexes(info._tableName, con);
         String alterTableOperations = buildAlterTableOperations(info, Tools.hasPrimaryKey(con, info._tableName), indexes);
         if (alterTableOperations != null) {
             if (stmt == null)
                 stmt = con.createStatement();
             String alterTableStatement = "ALTER TABLE " + info._tableName + ' ' + alterTableOperations;
-            _provider.getJournal().debug(alterTableStatement);
+            LOG.debug(alterTableStatement);
             stmt.execute(alterTableStatement);
         }
         return stmt;
