@@ -65,6 +65,8 @@ import static com.openexchange.usm.connector.commands.CommandConstants.TIME_ZONE
 import static com.openexchange.usm.connector.commands.CommandConstants.USER;
 import static com.openexchange.usm.connector.commands.CommandConstants.USERID;
 import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
+import static com.openexchange.usm.connector.commands.CommandConstants.START_DATE_CALENDAR;
+import static com.openexchange.usm.connector.commands.CommandConstants.END_DATE_CALENDAR;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
@@ -424,6 +426,8 @@ public abstract class BaseCommandHandler implements CommandHandler {
             config.put(TIME_ZONE, _session.getUserTimeZone().getID());
             config.put(START_DATE, String.valueOf(_session.getStartDate()));
             config.put(END_DATE, String.valueOf(_session.getEndDate()));
+            config.put(START_DATE_CALENDAR, String.valueOf(_session.getCalendarStartDate()));
+            config.put(END_DATE_CALENDAR, String.valueOf(_session.getCalendarEndDate()));
             config.put(FOLDER_TREE, _session.getPersistentField(FolderContentType.FOLDER_TREE));
             config.put(CONFLICT_RESOLUTION, _session.getConflictResolution());
             config.put(CONTEXT_UUID, String.valueOf(_session.getContextUUID()));
