@@ -81,10 +81,11 @@ public class ClearDataHandler extends NormalCommandHandler {
     public ResponseObject handleRequest() throws USMJSONAPIException {
         String tempid = getStringParameter(TEMPID, null);
         try {
-            if (tempid == null)
-                TempFileStorage.deleteTempFiles(_session);
-            else
+            if (tempid != null)
                 TempFileStorage.deleteTempFile(_session, tempid);
+            // no else case
+            // bug fix 36718: commands which may run in parallel shall not delete all files!
+                
             return new ResponseObject(ResponseStatusCode.SUCCESS);
         } catch (IOException e) {
             throw new USMJSONAPIException(
