@@ -52,7 +52,9 @@ package com.openexchange.usm.connector.commands;
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import java.io.EOFException;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.Writer;
+import java.util.UUID;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
@@ -65,6 +67,7 @@ import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.datatypes.contacts.Image;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.ServletConstants;
@@ -75,6 +78,8 @@ import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.json.streaming.ServerTempId;
 import com.openexchange.usm.json.streaming.ServerTempIdType;
+import com.openexchange.usm.util.TempFile;
+import com.openexchange.usm.util.TempFileStorage;
 import com.openexchange.usm.util.Toolkit;
 
 /**
@@ -238,11 +243,15 @@ public class DownloadDataHandler extends NormalCommandHandler {
         while (readPos < buffer.length && _responseStatus == ResponseStatusCode.SUCCESS) {
             try {
                 int read = is.read(buffer, readPos, buffer.length - readPos);
-                if (read < 0)
+                if (read < 0) {
+                    _servlet.getJournal().error(
+                        _session + " EOF reached after bytes: " + readPos + " expected: " + buffer.length);
                     _responseStatus = ResponseStatusCode.OX_SERVER_ERROR; // TODO use new status code for an unexpected short read ?
-                else
+                } else
                     readPos += read;
             } catch (IOException e) {
+                _servlet.getJournal().error(
+                    _session + " IOException after bytes: " + readPos + " expected: " + buffer.length, e);
                 _responseStatus = ResponseStatusCode.OX_SERVER_ERROR; // TODO use new status code for an unexpected short read ?
             }
         }
@@ -299,7 +308,37 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 return _object.getContentType().getTransferHandler().getAttachmentDataStream(_object, attachmentId, _offset, _realLength);
             }
             MailContentType mailContentType = (MailContentType) _object.getContentType();
-            return mailContentType.getMailAttachmentStreamFromStructureId(_session, _id.getFolderId(), _id.getObjectId(), _id.getAttachmentId());
+            TempFile tempFile;
+            String key = generateKeyFor(_session.getUser(), _session.getProtocol(), _session.getDevice());
+            String tempId = (String) _session.getCustomProperty(key + "_id");
+            String contentType = (String) _session.getCustomProperty(key + "_ct");
+            
+            if (_offset == 0) {
+                // read data once into a temporary file
+                tempId = UUID.randomUUID().toString();
+                _session.setCustomProperty(key + "_id", tempId);
+                tempFile = TempFileStorage.getTempFileForWrite(_session, tempId, _offset);
+
+                ResourceInputStream in = mailContentType.getMailAttachmentStreamFromStructureId(_session, _id.getFolderId(), _id.getObjectId(), _id.getAttachmentId());
+                contentType = in.getContentType();
+                _session.setCustomProperty(key + "_ct", contentType);
+                try {
+                    int blen = 65536;
+                    byte[] buf = new byte[blen];
+                    for (int read; (read = in.read(buf, 0, blen)) > 0;) {
+                        tempFile.write(buf, 0, read);
+                    }
+                }
+                finally {
+                    Toolkit.close(in);
+                    if (tempFile != null)
+                        tempFile.close();
+                }
+            }
+
+            tempFile = TempFileStorage.getTempFileForRead(_session, tempId);
+            return new TempFileResourceInputStream(tempFile, tempId, _session, contentType, !_moreAvailable);
+
         } catch (NumberFormatException ignored) {
             throw new USMJSONAPIException(
                 ConnectorBundleErrorCodes.DOWNLOAD_DATA_INVALID_ATTACHMENT_ID,
@@ -307,6 +346,10 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 "Invalid attachment id for '" + _id + '\'');
         } catch (USMException e) {
             throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.DOWNLOAD_DATA_ERROR_ACCESSING_PIM_ATTACHMENT, e);
+        } catch (IOException e) {
+            ResponseStatusCode code = ResponseStatusCode.INTERNAL_ERROR;
+            int errorCode = ConnectorBundleErrorCodes.DOWNLOAD_DATA_ERROR_ACCESSING_ATTACHMENT;
+            throw new USMJSONAPIException(errorCode, code, e.getMessage(), e);
         }
     }
 
@@ -350,4 +393,114 @@ public class DownloadDataHandler extends NormalCommandHandler {
     protected String[] getOptionalParameters() {
         return OPTIONAL_PARAMETERS;
     }
-}
+
+
+    private String generateKeyFor(String user, String protocol, String device) {
+        return new StringBuilder(128).append("__file_").append(user).append('_').append(protocol).append('_').append(device).toString();
+    }
+
+    
+    /**
+     * {@link TempFileResourceInputStream} Allows access to data stored in a temporary file for subsequent downloadData commands
+     * 
+     * @authors <a href="mailto:mgr@microdoc.de">Max Griessl</a>, <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
+     */
+    private static class TempFileResourceInputStream extends ResourceInputStream {
+    
+            private InputStream _in;
+            private final String _contentType;
+            private final long _contentLength;
+            private final boolean _deleteOnClose;
+            private final String _tempId;
+            private final Session _session;
+    
+            TempFileResourceInputStream(TempFile file, String tempId, Session session, String contentType, boolean deleteOnClose) throws IOException {
+                super();
+                _deleteOnClose = deleteOnClose;
+                _tempId = tempId;
+                _in = file.getInputStream();
+                _contentLength = file.getSize();
+                _contentType = contentType;
+                _session = session;
+            }
+    
+            private void ensureOpen() throws IOException {
+                if (null == _in) {
+                    throw new IOException("Stream already closed");
+                }
+            }
+    
+            @Override
+            public long getContentLength() {
+                return _contentLength;
+            }
+    
+            @Override
+            public String getContentType() {
+                return _contentType;
+            }
+    
+            @Override
+            public int read() throws IOException {
+                ensureOpen();
+                return _in.read();
+            }
+    
+            @Override
+            public int read(byte[] b) throws IOException {
+                ensureOpen();
+                return _in.read(b);
+            }
+    
+            @Override
+            public int read(byte[] b, int off, int len) throws IOException {
+                ensureOpen();
+                return _in.read(b, off, len);
+            }
+    
+            @Override
+            public void close() throws IOException {
+                InputStream in = _in;
+                if (null != in) {
+                    in.close();
+                    this._in = null;
+                }
+                if (_deleteOnClose) {
+                    TempFileStorage.deleteTempFile(_session, _tempId);
+                }
+                super.close();
+            }
+    
+            @Override
+            public long skip(long n) throws IOException {
+                ensureOpen();
+                return _in.skip(n);
+            }
+    
+            @Override
+            public int available() throws IOException {
+                ensureOpen();
+                return _in.available();
+            }
+    
+            @Override
+            public void mark(int readlimit) {
+                InputStream in = this._in;
+                if (null != in) {
+                    in.mark(readlimit);
+                }
+            }
+    
+            @Override
+            public void reset() throws IOException {
+                ensureOpen();
+                _in.reset();
+            }
+    
+            @Override
+            public boolean markSupported() {
+                InputStream in = this._in;
+                return null == in ? false : in.markSupported();
+            }
+        }
+    }
