@@ -149,7 +149,12 @@ public enum ErrorStatusCode {
      * The client requested multiple operations on the same UUID. This code will be reported for all operations with that UUID, and none
      * will be executed
      */
-    MULTIPLE_OPERATIONS_ON_SAME_UUID;
+    MULTIPLE_OPERATIONS_ON_SAME_UUID,
+    
+    /**
+     * The client requested a move for an object that is not existing any more in the source folder at the server (was moved or deleted by another client). 
+     */
+    OBJECT_DOES_NOT_EXIST_IN_SOURCE;
 
     public int getStatusCode() {
         return ordinal() + 1;
