@@ -66,6 +66,7 @@ import java.util.UUID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.log.LogProperties;
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.HttpSessionUtil;
@@ -128,6 +129,11 @@ public class LoginHandler extends BaseCommandHandler {
             throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.LOGIN_JSON_ERROR, e);
         }
         HttpSessionUtil.storeSession(getHttpSession(), randomHttpSessionID, usmSessionID);
+        
+        LogProperties.put(LogProperties.Name.SESSION_SESSION_ID, _session.getSessionId());
+        LogProperties.put(LogProperties.Name.SESSION_CONTEXT_ID, _session.getContextId());
+        LogProperties.put(LogProperties.Name.SESSION_USER_ID, _session.getUserIdentifier());
+        
         return new ResponseObject(ResponseStatusCode.SUCCESS, resultObject);
     }
 
