@@ -97,7 +97,7 @@ import com.openexchange.usm.util.Toolkit;
 
 public abstract class NormalCommandHandler extends BaseCommandHandler {
 
-    protected static final String GLOBAL_ADDRESS_BOOK_ID = "F_6";
+    protected static final String GLOBAL_ADDRESS_BOOK_ID = "6";
 
     private static final String DELETE_EXCEPTIONS = "delete_exceptions";
     
@@ -213,28 +213,7 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
                         }
                     }
                 } else if (CommandConstants.DISTRIBUTION_LIST.equals(fieldName)) {
-                    fieldType.storeInJSONObject(o.getSession(), newObject, fieldName, v);
-                    JSONArray list = newObject.getJSONArray(CommandConstants.DISTRIBUTION_LIST);
-                    JSONArray newList = new JSONArray();
-                    int length = list.length();
-                    for (int j = 0; j < length; j++) {
-                        ContactDistributionMember dMember = new ContactDistributionMember(list.getJSONObject(j));
-                        JSONObject jObj = dMember.toJSONObject();
-                        String user_id = dMember.getUser_id();
-                        if (user_id != null) {
-                            try {
-                                DataObject cachedListMember = getDefaultContacsFolder() != null ? o.getSession().getCachedFolderElement(getDefaultContacsFolder().getID(), o.getContentType(), user_id) : null;
-                                if (cachedListMember == null) cachedListMember = o.getSession().getCachedFolderElement(GLOBAL_ADDRESS_BOOK_ID, o.getContentType(), user_id);
-                                UUID uuid = cachedListMember != null ? cachedListMember.getUUID() : null;
-                                if (uuid != null) jObj.put(UUID_KEY, uuid.toString());
-                            } catch (NumberFormatException ignored) {
-                                // do nothing
-                            } catch (USMException ignored) {
-                                // do nothing
-                            }
-                        }
-                        newList.put(jObj);
-                    }
+                    JSONArray newList = createDistributionListJSONArrayForResult(o, newObject, fieldType, v, fieldName);
                     newObject.put(CommandConstants.DISTRIBUTION_LIST, newList);
                 } else if (o instanceof Folder && TITLE.equals(fieldName)) {
                     String folderTitleForClient = generateFolderTitleForClient((Folder) o, v);
@@ -286,6 +265,32 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         }
         return newObject;
     }
+
+    private JSONArray createDistributionListJSONArrayForResult(DataObject o, JSONObject newObject, DataType<?> fieldType, Object v, String fieldName) throws JSONException {
+        fieldType.storeInJSONObject(o.getSession(), newObject, fieldName, v);
+        JSONArray list = newObject.getJSONArray(CommandConstants.DISTRIBUTION_LIST);
+        JSONArray newList = new JSONArray();
+        int length = list.length();
+        for (int j = 0; j < length; j++) {
+            ContactDistributionMember dMember = new ContactDistributionMember(list.getJSONObject(j));
+            JSONObject jObj = dMember.toJSONObject();
+            String user_id = dMember.getUser_id();
+            if (user_id != null) {
+                try {
+                    DataObject cachedListMember = getDefaultContacsFolder() != null ? o.getSession().getCachedFolderElement(getDefaultContacsFolder().getID(), o.getContentType(), user_id) : null;
+                    if (cachedListMember == null) cachedListMember = o.getSession().getCachedFolderElement(GLOBAL_ADDRESS_BOOK_ID, o.getContentType(), user_id);
+                    UUID uuid = cachedListMember != null ? cachedListMember.getUUID() : null;
+                    if (uuid != null) jObj.put(UUID_KEY, uuid.toString());
+                } catch (NumberFormatException ignored) {
+                    // do nothing
+                } catch (USMException ignored) {
+                    // do nothing
+                }
+            }
+            newList.put(jObj);
+        }
+        return newList;
+    }
     
     protected Folder getDefaultCalendarFolder() throws StorageAccessException, USMStorageException {
         if (_defaultCalendarFolder == null)
