@@ -48,7 +48,12 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.HOST;
+import static com.openexchange.usm.connector.commands.CommandConstants.PORT;
+import static com.openexchange.usm.connector.commands.CommandConstants.PUSH_TYPE_NONE;
+import static com.openexchange.usm.connector.commands.CommandConstants.PUSH_TYPE_UDP;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.TYPE;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import javax.servlet.http.HttpServletRequest;
