@@ -359,32 +359,25 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		}
 	}
 
-   
     private BitSet getStandardFolderDeletionsFromSyncResult() {
-        BitSet deletedStandardFolders = new BitSet(); // all standard folder types that were deleted
-        BitSet createdStandardFolders = new BitSet(); // all standard folder types that were created
-        for (DataObject o : _syncResult.getChanges()) {
-            if (o.getChangeState() == ChangeState.DELETED) {
-                int standardFolderType = getRequiredStandardFolderType(o, false);
-                if (standardFolderType > 0)
-                    deletedStandardFolders.set(standardFolderType);
-            } else if (o.getChangeState() == ChangeState.CREATED) {
-                int standardFolderType = getRequiredStandardFolderType(o, false);
-                if (standardFolderType > 0)
-                    createdStandardFolders.set(standardFolderType);
-            } else if (o.getChangeState() == ChangeState.MODIFIED) {
-                int oldStandardFolderType = getRequiredStandardFolderType(o, true);
-                int newStandardFolderType = getRequiredStandardFolderType(o, false);
-                if (oldStandardFolderType != newStandardFolderType) {
-                    if (oldStandardFolderType > 0)
-                        deletedStandardFolders.set(oldStandardFolderType);
-                    if (newStandardFolderType > 0)
-                        createdStandardFolders.set(newStandardFolderType);
-                }
-            }
+        return getStandardFolderDeletionsFromSyncResultCore(_syncResult.getNewState());
+    }
+
+    // core function for testing
+    public static BitSet getStandardFolderDeletionsFromSyncResultCore(DataObject[] newSyncState) {
+        
+        BitSet notExistingStandardFolders = new BitSet(); // all standard folder types that do not exist
+        // initialize the bit set
+        notExistingStandardFolders.set(1,4);
+        notExistingStandardFolders.set(7);
+        notExistingStandardFolders.set(9,13);
+        
+        for (DataObject o : newSyncState) {
+            int standardFolderType = getRequiredStandardFolderType(o, false);
+            if (standardFolderType > 0 && o.getChangeState() != ChangeState.DELETED)
+                notExistingStandardFolders.clear(standardFolderType);
         }
-        deletedStandardFolders.andNot(createdStandardFolders);
-        return deletedStandardFolders;
+        return notExistingStandardFolders;
     }
 
     /**
