@@ -290,4 +290,10 @@ public class JSONSessionInitializer implements SessionInitializer {
     public boolean objectsSynchronizedByUUID() {
         return true;
     }
+
+    @Override
+    public void updateDefaultFolders(Session session, JSONObject ajaxConfiguration) throws USMException {
+        // TODO Auto-generated method stub
+        
+    }
 }
