@@ -146,6 +146,10 @@ public class USMJSONServlet extends HttpServlet {
     private transient int _timefilterLimitPast;
 
     private transient int _timefilterLimitFuture;
+    
+    private transient int _timefilterCalendarLimitPast;
+
+    private transient int _timefilterCalendarLimitFuture;
 
     private transient int _inboxPollingInterval;
 
@@ -203,6 +207,14 @@ public class USMJSONServlet extends HttpServlet {
                 ConfigurationProperties.JSON_SERVLET_TIMEFILTER_LIMIT_FUTURE_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_TIMEFILTER_LIMIT_FUTURE_DEFAULT,
                 false);
+            _timefilterCalendarLimitPast = _configurationManager.getProperty(
+                ConfigurationProperties.JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_PAST_PROPERTY,
+                ConfigurationProperties.JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_PAST_DEFAULT,
+                false);
+            _timefilterCalendarLimitFuture = _configurationManager.getProperty(
+                ConfigurationProperties.JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_FUTURE_PROPERTY,
+                ConfigurationProperties.JSON_SERVLET_TIMEFILTER_CALENDAR_LIMIT_FUTURE_DEFAULT,
+                false);
             _inboxPollingInterval = _configurationManager.getProperty(
                 ConfigurationProperties.JSON_SERVLET_INBOX_POLLING_INTERVAL_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_INBOX_POLLING_INTERVAL_DEFAULT,
@@ -524,6 +536,16 @@ public class USMJSONServlet extends HttpServlet {
     public int getTimefilterLimitFuture() {
         return _timefilterLimitFuture;
     }
+    
+    
+    public int getTimefilterCalendarLimitPast() {
+        return _timefilterCalendarLimitPast;
+    }
+
+    
+    public int getTimefilterCalendarLimitFuture() {
+        return _timefilterCalendarLimitFuture;
+    }
 
     public int getInboxPollingInterval() {
         return _inboxPollingInterval;
