@@ -235,7 +235,7 @@ public abstract class AbstractMimeMailBuilder {
     	    part.removeHeader(header);
     	}
     }
-
+    
     protected static void appendHeaderConditional(Part part, String header, String value) throws MessagingException {
         if (isValueSet(value)) {
             try {
@@ -523,8 +523,9 @@ public abstract class AbstractMimeMailBuilder {
     			String contDispAsString = buildContentDispositionAsString(headers.get(_CONTENT_DISPOSITION));
     			part.setDisposition(contDispAsString);
     		}
-    		setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, getValue(headers, CONTENT_TRANSFER_ENCODING,
-    				0, null));
+            if (headers != null && part.getHeader(CONTENT_TRANSFER_ENCODING_UPPER) == null) {
+                setHeaderConditional(part, CONTENT_TRANSFER_ENCODING_UPPER, getValue(headers, CONTENT_TRANSFER_ENCODING, 0, null));
+            }
     		//add (or replace with) the original headers
     		if (headers != null && headers.has(_X_ORIGINAL_HEADERS)) {
     			Enumeration<Header> originalHeadersMap = parseXOriginalHeaders(headers.getString(_X_ORIGINAL_HEADERS));
