@@ -46,37 +46,41 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.ox_json.impl;
 
-import static com.openexchange.usm.ox_json.JSONResultType.JSONArray;
-import static com.openexchange.usm.ox_json.JSONResultType.JSONObject;
-import static com.openexchange.usm.ox_json.JSONResultType.String;
+import static com.openexchange.usm.api.ox.json.JSONResultType.JSONArray;
+import static com.openexchange.usm.api.ox.json.JSONResultType.JSONObject;
+import static com.openexchange.usm.api.ox.json.JSONResultType.String;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import com.openexchange.usm.api.exceptions.USMIllegalStateException;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
 
 public abstract class AbstractJSONResult implements JSONResult {
 
-	public JSONArray getJSONArray() {
-		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_0, getErrorMessage(JSONArray));
-	}
+    @Override
+    public JSONArray getJSONArray() {
+        throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_0, getErrorMessage(JSONArray));
+    }
 
-	public JSONObject getJSONObject() {
-		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_1, getErrorMessage(JSONObject));
-	}
+    @Override
+    public JSONObject getJSONObject() {
+        throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_1, getErrorMessage(JSONObject));
+    }
 
-	public String getString() {
-		throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_2, getErrorMessage(String));
-	}
+    @Override
+    public String getString() {
+        throw new USMIllegalStateException(OXJSONErrorCode.ABSTRACT_JSONRESULT_NUMBER_2, getErrorMessage(String));
+    }
 
-	private String getErrorMessage(JSONResultType expected) {
-		return "Result from OX server is a " + getResultType() + ", expected " + expected;
-	}
+    private String getErrorMessage(JSONResultType expected) {
+        return "Result from OX server is a " + getResultType() + ", expected " + expected;
+    }
 
-	@Override
-	public String toString() {
-		return "OX Result: " + toJSONString();
-	}
+    @Override
+    public String toString() {
+        return "OX Result: " + toJSONString();
+    }
 }
