@@ -51,13 +51,15 @@ package com.openexchange.usm.ox_json.impl;
 
 import static com.openexchange.usm.util.OXJSONUtil.DATA_FIELD;
 import static com.openexchange.usm.util.OXJSONUtil.ERROR_FIELD;
-import static com.openexchange.usm.util.OXJSONUtil._RELOGIN_ERROR_CODES;
 import static com.openexchange.usm.util.OXJSONUtil.isOXError;
+
 import java.io.IOException;
+
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.json.JSONTokener;
+
 import com.openexchange.usm.api.ox.json.JSONResult;
 import com.openexchange.usm.api.ox.json.JSONResultType;
 import com.openexchange.usm.util.OXJSONUtil;
@@ -140,17 +142,8 @@ public class OXJSONSupport {
         return expected == null || expected == actual;
     }
 
-    public static void setReloginErrorCodes(String reloginErrorCodes) {
-        _RELOGIN_ERROR_CODES.clear();
-        for (String s : reloginErrorCodes.split(",")) {
-            String code = s.trim();
-            if (code.length() > 0)
-                _RELOGIN_ERROR_CODES.add(code);
-        }
-    }
-    
 
     public static boolean shouldPerformNewLogin(JSONResult result) {
-        return result.getResultType() == JSONResultType.Error && _RELOGIN_ERROR_CODES.contains(OXJSONUtil.getJSONErrorCode(result.getJSONObject()));
+        return result.getResultType() == JSONResultType.Error &&  OXJSONUtil.isReloginErrorCode(result.getJSONObject());
     }
 }
