@@ -53,7 +53,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import org.apache.commons.httpclient.Header;
 import org.apache.commons.httpclient.HttpMethod;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.session.Session;
 
 /**
@@ -92,13 +92,15 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
 
     private final String _description;
 
+    private final long _startTime;
+
     private InputStream _inputStream;
 
     private long _lastActivity;
 
     private boolean _closed;
 
-    public ResourceInputStreamImpl(OXJSONAccessImpl oxjsonAccess, Session session, OXConnectionData connectionData, HttpMethod method, String contentType, String description) throws IOException {
+    public ResourceInputStreamImpl(OXJSONAccessImpl oxjsonAccess, Session session, OXConnectionData connectionData, HttpMethod method, String contentType, String description, long startTime) throws IOException {
         super();
         _description = description;
         _oxJSONAccess = oxjsonAccess;
@@ -108,6 +110,7 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
         _contentLength = getContentLength(method);
         _lastActivity = System.currentTimeMillis();
         _connectionData = connectionData;
+        _startTime = startTime;
         connectionData.setCurrentResourceInputStream(this);
     }
 
@@ -143,6 +146,8 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
             if (_connectionData.getCurrentResourceInputStream() == this)
                 _connectionData.setCurrentResourceInputStream(null);
             _oxJSONAccess.releaseLock(_session);
+            if (_startTime != 0L)
+                OXJSONAccessImpl.collectOXStatistics(_session, _startTime);
         }
     }
 
@@ -156,7 +161,7 @@ public class ResourceInputStreamImpl extends ResourceInputStream {
             close();
         return result;
     }
-
+    
     @Override
     public synchronized void reset() throws IOException {
         getInputStream().reset();
