@@ -46,66 +46,50 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.session.dataobject;
 
 import java.util.HashMap;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import org.apache.commons.logging.Log;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeListener;
-import com.openexchange.usm.api.contenttypes.ContentTypeManager;
-import com.openexchange.usm.api.contenttypes.FieldMapStorage;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.FieldMapStorage;
 
-public class FieldMapStorageImpl implements FieldMapStorage, ContentTypeListener {
-	private final static FieldMapStorageImpl INSTANCE = new FieldMapStorageImpl();
+public class FieldMapStorageImpl implements FieldMapStorage {
 
-	public static FieldMapStorageImpl getInstance() {
-		return INSTANCE;
-	}
+    private final static FieldMapStorageImpl INSTANCE = new FieldMapStorageImpl();
 
-	private final ConcurrentMap<ContentType, Map<String, Integer>> _fieldNameToIndexMapTable = new ConcurrentHashMap<ContentType, Map<String, Integer>>(
-			16, 0.75f, 1);
+    public static FieldMapStorageImpl getInstance() {
+        return INSTANCE;
+    }
 
-	private ContentTypeManager _contentTypeManager;
-	private Log _journal;
+    private final ConcurrentMap<ContentType, Map<String, Integer>> _fieldNameToIndexMapTable = new ConcurrentHashMap<ContentType, Map<String, Integer>>(
+        16,
+        0.75f,
+        1);
 
-	public FieldMapStorageImpl() {
-	}
+    @Override
+    public void addedContentType(ContentType typeAdded) {
+        _fieldNameToIndexMapTable.remove(typeAdded);
+    }
 
-	public void activate(Log journal, ContentTypeManager manager) {
-		_journal = journal;
-		_contentTypeManager = manager;
-		_contentTypeManager.addContentTypeListener(this);
-		_journal.info("USM FieldMapStorage activated");
-	}
+    @Override
+    public void removedContentType(ContentType typeRemoved) {
+        _fieldNameToIndexMapTable.remove(typeRemoved);
+    }
 
-	public void deactivate() {
-		_contentTypeManager.removeContentTypeListener(this);
-		_journal.info("USM FieldMapStorage deactivated");
-		_contentTypeManager = null;
-		_journal = null;
-	}
-
-	public void addedContentType(ContentType typeAdded) {
-		_fieldNameToIndexMapTable.remove(typeAdded);
-	}
-
-	public void removedContentType(ContentType typeRemoved) {
-		_fieldNameToIndexMapTable.remove(typeRemoved);
-	}
-
-	public Map<String, Integer> getFieldNameToIndexMap(ContentType contentType) {
-		Map<String, Integer> result = _fieldNameToIndexMapTable.get(contentType);
-		if (result == null) { //TODO: initialize in activate
-			result = new HashMap<String, Integer>();
-			ContentTypeField[] fields = contentType.getFields();
-			for (int i = 0; i < fields.length; i++)
-				result.put(fields[i].getFieldName(), i);
-			_fieldNameToIndexMapTable.putIfAbsent(contentType, result);
-		}
-		return result;
-	}
+    @Override
+    public Map<String, Integer> getFieldNameToIndexMap(ContentType contentType) {
+        Map<String, Integer> result = _fieldNameToIndexMapTable.get(contentType);
+        if (result == null) { // TODO: initialize in activate
+            result = new HashMap<String, Integer>();
+            ContentTypeField[] fields = contentType.getFields();
+            for (int i = 0; i < fields.length; i++)
+                result.put(fields[i].getFieldName(), i);
+            _fieldNameToIndexMapTable.putIfAbsent(contentType, result);
+        }
+        return result;
+    }
 }
