@@ -481,7 +481,7 @@ public class SessionImpl implements Session {
         return result;
     }
 
-    private void markFolderHierarchyDirty() {
+    public void markFolderHierarchyDirty() {
         foldersChanged(FOLDER_HIERARCHY_NEEDS_SYNCHRONIZATION);
     }
 
@@ -961,7 +961,7 @@ public class SessionImpl implements Session {
 
     @Override
     public boolean needsSynchronization(String folderID) {
-        return Toolkit.provided(folderID) ? !_syncedFolderContent.containsKey(folderID) : isFolderHierarchySynchronized();
+        return Toolkit.provided(folderID) ? !_syncedFolderContent.containsKey(folderID) : !isFolderHierarchySynchronized();
     }
 
     private boolean isFolderHierarchySynchronized() {
