@@ -604,6 +604,24 @@ public class SessionManagerImpl implements SessionManager {
         }
     }
 
+    @Override
+    public void defaultFoldersChanged(int contextId, int userId) {
+        SessionID[] sessions = _sessionStorage.getActiveSessions(new UserID(contextId, userId));
+        if (sessions != null) {
+            for (SessionID session : sessions) {
+                SessionImpl s = _sessionStorage.getSession(session);
+                if (s != null) {
+                    s.markFolderHierarchyDirty();
+                    try {
+                        s.getSessionInitializer().updateDefaultFolders(s, null);
+                    } catch (USMException e) {
+                        LOG.error("Error while updating the default mail folders: " + e.getErrorMessage(), e);
+                    }
+                }
+            }
+        }
+    }
+
     public boolean isEmailPullEnabled() {
         return _waitForChangesEmailMinPullDelay >= 0;
     }
