@@ -96,6 +96,13 @@ public class TempFile implements Closeable, InputStreamProvider {
         _randomAccessFile = new RandomAccessFile(file, "r");
     }
 
+    public String getFileName() {
+        String fileName = "";
+        if (_managedFile != null)
+            fileName = _managedFile.getFile().getName();
+        return fileName;
+    }
+
     private void seek(long offset) throws IOException {
         try {
             _randomAccessFile.seek(offset);
@@ -106,9 +113,22 @@ public class TempFile implements Closeable, InputStreamProvider {
     }
 
     public void write(byte[] data) throws IOException {
+        write(data, 0, data.length);
+    }
+
+    /**
+     * Writes <code>len</code> bytes from the specified byte array
+     * starting at offset <code>off</code> to this file.
+     *
+     * @param      data   the data.
+     * @param      offset the start offset in the data.
+     * @param      len    the number of bytes to write.
+     * @exception  IOException  if an I/O error occurs.
+     */
+    public void write(byte[] data, int offset, int len) throws IOException {
         if (_randomAccessFile == null)
             throw new IOException("Can not access TempFile: Not open for write access");
-        _randomAccessFile.write(data);
+        _randomAccessFile.write(data, offset, len);
         if (_managedFile != null)
             _managedFile.touch();
     }
